r5332: Auto commit for Debian build
[puri.git] / src.lisp
index 8d98c1909b77474fceaa707eee489d0b48b35b46..f16cc47948ccdd8a2274bbb7c5c73c1c9aad7352 100644 (file)
--- a/src.lisp
+++ b/src.lisp
@@ -1,4 +1,4 @@
;; -*- mode: common-lisp; package: net.uri -*-
 ;; Support for URIs in Allegro.
 ;; For general URI information see RFC2396.
 ;;
@@ -22,7 +22,7 @@
 ;; Original version from ACL 6.1:
 ;; uri.cl,v 2.3.6.4.2.1 2001/08/09 17:42:39 layer
 ;;
-;; $Id: src.lisp,v 1.1 2003/07/18 20:34:23 kevin Exp $
+;; $Id: src.lisp,v 1.4 2003/07/19 03:12:18 kevin Exp $
 
 (defpackage #:puri
   (:use #:cl)
    #:unintern-uri
    #:do-all-uris))
 
-(in-package :net.uri)
+(in-package #:puri)
 
 (eval-when (compile) (declaim (optimize (speed 3))))
 
+
 (eval-when (:compile-toplevel :load-toplevel :execute)
   (defvar if*-keyword-list '("then" "thenret" "else" "elseif")))
 
-#-allegro
-(define-condition parse-error (error)
-  ()
-  )
-
+#-(or allegro lispworks)
+(define-condition parse-error (error)  ())
 
 (defun .parse-error (fmt &rest args)
   #+allegro (apply #'excl::.parse-error fmt args)
@@ -85,7 +83,6 @@
 
 #-allegro (defvar *current-case-mode* :case-insensitive-upper)
 
-;; From Larry Hunter with modifications
 (defun position-char (char string start max)
   (declare (optimize (speed 3) (safety 0) (space 0))
           (fixnum start max) (simple-string string))
@@ -759,6 +756,7 @@ URI ~s contains illegal character ~s at position ~d."
        (sb-kernel:shrink-vector new-string new-i)
        #-(or allegro sbcl)
        (subseq new-string 0 new-i)
+       #+(or allegro sbcl)
        new-string)
     (if* (char= #\% (setq ch (schar string i)))
        then (when (> (+ i 3) max)
@@ -885,6 +883,7 @@ URI ~s contains illegal character ~s at position ~d."
        (sb-kernel:shrink-vector new-string (incf new-i))
        #-(or allegro sbcl)
        (subseq new-string 0 (incf new-i))
+       #+(or allegro sbcl)
        new-string)
     (setq ci (char-int (setq c (schar string i))))
     (if* (or (null reserved-chars)
@@ -1285,9 +1284,9 @@ excl::
 #+allegro
 (locally (declare (special std-lisp-readtable))
   (let ((*readtable* std-lisp-readtable))
-    (set-dispatch-macro-character #\# #\u #'net.uri::sharp-u)))
+    (set-dispatch-macro-character #\# #\u #'puri::sharp-u)))
 #-allegro
-(set-dispatch-macro-character #\# #\u #'net.uri::sharp-u)
+(set-dispatch-macro-character #\# #\u #'puri::sharp-u)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -1,4 +1,4 @@
-;; -*- mode: common-lisp; package: net.uri -*-
+;; -*- mode: common-lisp; package: puri -*-
 ;; Support for URIs in Allegro.
 ;; For general URI information see RFC2396.